pub struct SCContentFilter { /* private fields */ }Implementations
Sourceimpl SCContentFilter
impl SCContentFilter
pub fn new() -> Retained<Self>
pub fn init_with_desktop_independent_window( this: Allocated<Self>, window: &SCWindow, ) -> Retained<Self>
pub fn init_with_display_exclude_windows( this: Allocated<Self>, display: &SCDisplay, excluded: &NSArray<SCWindow>, ) -> Retained<Self>
pub fn init_with_display_include_windows( this: Allocated<Self>, display: &SCDisplay, included: &NSArray<SCWindow>, ) -> Retained<Self>
pub fn init_with_display_exclude_applications( this: Allocated<Self>, display: &SCDisplay, applications: &NSArray<SCRunningApplication>, excepting_windows: &NSArray<SCWindow>, ) -> Retained<Self>
pub fn init_with_display_include_applications( this: Allocated<Self>, display: &SCDisplay, applications: &NSArray<SCRunningApplication>, excepting_windows: &NSArray<SCWindow>, ) -> Retained<Self>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for SCContentFilter
impl AsRef<AnyObject> for SCContentFilter
Sourceimpl AsRef<NSObject> for SCContentFilter
impl AsRef<NSObject> for SCContentFilter
Sourceimpl AsRef<SCContentFilter> for SCContentFilter
impl AsRef<SCContentFilter> for SCContentFilter
Sourceimpl Borrow<AnyObject> for SCContentFilter
impl Borrow<AnyObject> for SCContentFilter
Sourceimpl Borrow<NSObject> for SCContentFilter
impl Borrow<NSObject> for SCContentFilter
Sourceimpl ClassType for SCContentFilter
impl ClassType for SCContentFilter
Sourceconst NAME: &'static str = "SCContentFilter"
const NAME: &'static str = "SCContentFilter"
Sourcetype ThreadKind = <<SCContentFilter as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<SCContentFilter as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for SCContentFilter
impl Debug for SCContentFilter
Sourceimpl Deref for SCContentFilter
impl Deref for SCContentFilter
impl DowncastTarget for SCContentFilter
impl Eq for SCContentFilter
Sourceimpl Hash for SCContentFilter
impl Hash for SCContentFilter
Sourceimpl Message for SCContentFilter
impl Message for SCContentFilter
Sourceimpl NSObjectProtocol for SCContentFilter
impl NSObjectProtocol for SCContentFilter
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref